import setuptools

setuptools.setup(
    name="maxflow", # Replace with your own username
    version="0.0.1", # Will be updated to 0.1 when the first working version becomes ready.
    author="Touqir Sajed",
    author_email="shuhash6@gmail.com",
    description="",
    # long_description=long_description,
    # long_description_content_type="text/markdown",
    # url="https://github.com/pypa/sampleproject",
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 1 - Planning",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    # python_requires='>=3.6',
)